@@ -19,6 +19,12 @@
 #
 """get version for the module
 """
+
+__authors__ = [
+    # alphabetical order by last name
+    'Thomas Chiroux', ]
+
+
 import pkg_resources
 
 __version__ = "unknown"
@@ -27,4 +33,4 @@ try:
     __version__ = pkg_resources.resource_string("attowiki",
                                                 "RELEASE-VERSION").strip()
 except IOError:
-    __version__ = "0.0.0"
\ No newline at end of file
+    __version__ = "0.0.0"
